@@ -1,11 +1,6 @@
 from django.core.files.storage import Storage
-from celery import task
 from .signals import transaction_signals
-
-
-@task
-def delete_file(storage, filename):
-    storage.delete(filename)
+from .tasks import delete_file
 
 
 class DelayHook(Storage):
